  /*
 * RFID_combination_lock_v1.9
 * ***********DO NOT LOAD SKETCH UNTIL VALUES ON LINES 60 AND 61 ARE SET OR SERVO DAMAGE COULD RESULT***************
 * 12 RFID objects are used to enter a combination.
 * each of the objects is associated with an animal, goat, sheep, cow, rabbit
 * to enter the code it will be waving objects near RFID sensor in a specific order to complete the combo
 * combos visable on lines 208-220
 * MP3 board will allow the playing of pre recorded messages with the entry of the code. 
 * 16 animal cards programmed into the system - graphic stickers to be created for each card
 * last update 6-25-23 10:30 PM E.linville
 * Creative commons licence - Atribution, non-commercial, share alike - for definition goto: 
 * https://creativecommons.org/get-cc-savvy/breaking-cc-licenses/
 */
#include <Servo.h>
#include <EEPROM.h>
#include <SPI.h>
#include <MFRC522.h>
#define SS_PIN 53
#define RST_PIN 9
#define LED 25
byte readCard[4];
String tag_UID1 = "304FA7B1"; //cow card
String tag_UID2 = "222B82EE"; //goat card
String tag_UID3 = "E3423BAF"; //rabbit card
String tag_UID4 = "4A21BCA"; //snake card
String tag_UID5 = "4B2171A"; //hippo card
String tag_UID6 = "F927FEFB"; //lion card
String tag_UID7 = "93BD24AF"; //duck card
String tag_UID8 = "1DBDFF6C"; //bear card
String tag_UID9 = "DCEA3515"; //sheep card
String tag_UID10 = "CF55E5E"; //rat card
String tag_UID11 = "19F13640"; //allagater
String tag_UID12 = "90FF93B1"; //cat
String tag_UID13 = "2E56E12"; //kangaroo
String tag_UID14 = "2E6DEA2"; //chicken card
String tag_UID15 = "AEA8EE1"; //catapillar card
String tag_UID16 = "7ED7F11"; //goose card
String tag_UID17 = "27BDE65B"; //wristband master unlock
String tag_UID18 = "D72C7252"; //wristband master lock
String tagID = ""; //string to be filled with read card Id numbers
//outputs to control the MP3 board
const int I00=32;
const int I01=30;
const int I02=28;
const int I03=26;
const int I04=24;
const int I05=22;
const int busy=23; //feed back pin from MP3 board, LOW when playing, HIGH when idle
const int shutOff = 12; //trigger pin for pololu power control board - HIGH to shut off board
unsigned long time; //running timer that starts when board powers up
unsigned long timeCapture=0; //variable to capture time and compare against a variable
int timerVoice = 90; //45 seconds on the clock before shutdown (90 to allow voice prompts to play correctly + a bit extra to be fair)
int adventureSwitch=0; //used to route where the code is with the voice prompts
bool correctEntry=true; //if correct entry remains true then the box will open if not start over
int attemptNumber=1; //variable to keep track of number of attempts 1-3
int songTrack = 0; //used to trigger audio files inside of MP3tracks()

////////////////// alter the following two values to the servo position numbers that you got with the test code previously/////////////////
//**********************do no load sketch until these two variables are set or damage to the servo could result***************************
int servoOpen=1590; //value to set the servo to the open position  <<<<<<<<<<----------------------------<<
int servoClosed=1350; //value to set the servo the closed position <<<<<<<<<<----------------------------<<
Servo boxServo; //define servo name

MFRC522 mfrc522(SS_PIN, RST_PIN); // Create MFRC522 RFID board instance

void setup()
{
  Serial.begin(115200);// Initialize serial communications with the PC - be sure to set your serial monitor to 115200 in lower right corner
  SPI.begin(); // Start the SPI bus
  mfrc522.PCD_Init(); // Initialise MFRC522 RFID board

  boxServo.attach(2); //attach the servo to pin 2 (yellow wire)
  //set the pins to input/output modes
  pinMode(I00, OUTPUT);
  pinMode(I01, OUTPUT);
  pinMode(I02, OUTPUT);
  pinMode(I03, OUTPUT);
  pinMode(I04, OUTPUT);
  pinMode(I05, OUTPUT);
  pinMode(shutOff, OUTPUT); //trigger pin to pololu power control board
  pinMode(busy, INPUT); //feedback pin from MP3 board - LOW when busy(playing), HIGH when idle
  
  digitalWrite(shutOff, LOW); //turn off shutOff pin
  Serial.println("-------------------- Rfid combination lock with MP3 V1.9--------------------------------");
  boxServo.writeMicroseconds (servoClosed);//right max (verify the box is locked)
  
  //the following line will read from EEPROM and set which combination of cards will be used to open the box, each failure indexes the number
  attemptNumber=EEPROM.read(0); //read the saved value from EEPROM into attemptNumber. 
  
            //attemptNumber=1; //temp force attempt number to 1 to use the same cards over and over, remove after testing
  Serial.print("attempt number == "); Serial.println(attemptNumber); //show on SM where attempt number is
 
  songTrack=1; MP3tracks(); //sets the song track to 1 then triggers play cycle
  /*voice: "greetings adventurers, and welcome to your final task,one by one place the animals inside the fence in this order then remove
   * you have 60 seconds to enter the code before shutdown" */
  while(digitalRead(busy)==LOW){/* wait here until the entire message is played*/}
  
  action(); //goto action the first time to deliver the voice prompt
  //boxServo.writeMicroseconds (servoOpen);//right max (verify the box is un-locked) used only for testing
  
} //end of setup

void loop()
{
  time=millis(); //make time = current lifetime count of board
  if (time>timeCapture+1100){timeCapture=time; timerVoice--; countDown(); Serial.println ("timer pulse");}
  if (timerVoice==-1){songTrack=46; MP3tracks(); shutDown();}
  
//if mp3 is already playing, save here then when digitalRead of busy pin is HIGH play the track
//one for countDown() and one for action()
//mp3tracks() will only be triggered from here
if (digitalRead(busy)==HIGH) // if mp3 player is idle
  {
    if (songTrack<47){MP3tracks();}
  }

  //Wait until new tag is available
  while (readID()) //while (readID == true) -> if a new card has been sensed
  {
    Serial.print(tagID);
    Serial.println(" ");
    //WRISTBAND MASTER UNLOCK UID CODES
    if (tagID == tag_UID17){Serial.println("wristband master - unlock"); 
      boxServo.writeMicroseconds(servoOpen); return; //exit back to loop
      //voice:** no voice reaction to master wristbands
      }
    if (tagID == tag_UID18){Serial.println("wristband master - lock"); 
      boxServo.writeMicroseconds(servoClosed); return; //exit back to loop
      //voice:** no voice reaction to master wristbands
      }

    action(); //goto action to act on card read
  }
 
}//end of loop
  //Read new tag if available

boolean readID()
  {
    //Check if a new tag is detected or not. If not return.
    if ( ! mfrc522.PICC_IsNewCardPresent())
    {
      return false;
    }
    //Check if a new tag is readable or not. If not return.
    if ( ! mfrc522.PICC_ReadCardSerial())
    {
      return false;
    }
    tagID = "";
    // Read the 4 byte UID
    for ( uint8_t i = 0; i < 4; i++)
    {
      //readCard[i] = mfrc522.uid.uidByte[i];
      tagID.concat(String(mfrc522.uid.uidByte[i], HEX)); // Convert the UID to a single String
    }
    tagID.toUpperCase();
    mfrc522.PICC_HaltA(); // Stop reading
    return true;
  }

  void action() //come here if a card is detected to act upon it
  {
 
  
    if(adventureSwitch>0)
    {
      if (tagID == tag_UID1){Serial.println("cow card");songTrack=15; MP3tracks(); }
      //voice: cow is in the yard
      if (tagID == tag_UID2){Serial.println("goat card");songTrack=16; MP3tracks(); }
      //voice: goat is in the yard
      if (tagID == tag_UID3){Serial.println("rabbit card");songTrack=17; MP3tracks(); }
      //voice: rabbit is in the yard
      if (tagID == tag_UID4){Serial.println("snake card");songTrack=18; MP3tracks(); }
      //voice: snake is in the yard
      if (tagID == tag_UID5){Serial.println("hippo card");songTrack=19; MP3tracks(); }
      //voice: hippo is in the yard
      if (tagID == tag_UID6){Serial.println("lion card");songTrack=20; MP3tracks(); }
      //voice: lion is in the yard
      if (tagID == tag_UID7){Serial.println("duck card");songTrack=21; MP3tracks(); }
      //voice: owl is in the yard
      if (tagID == tag_UID8){Serial.println("bear card");songTrack=22; MP3tracks(); }
      //voice: bear is in the yard
      if (tagID == tag_UID9){Serial.println("sheep card");songTrack=23; MP3tracks(); }
      //voice: koala is in the yard
      if (tagID == tag_UID10){Serial.println("rat card");songTrack=24; MP3tracks(); }
      //voice: rat is in the yard
      if (tagID == tag_UID11){Serial.println("aligator card");songTrack=25; MP3tracks(); }
      //voice: aligator is in the yard
      if (tagID == tag_UID12){Serial.println("cat card");songTrack=26; MP3tracks(); }
      //voice: cat is in the yard
      if (tagID == tag_UID13){Serial.println("kangaroo card");songTrack=27; MP3tracks(); }
      //voice: kangaroo is in the yard
      if (tagID == tag_UID14){Serial.println("chicken card");songTrack=28; MP3tracks(); }
      //voice: chicken is in the yard
      if (tagID == tag_UID15){Serial.println("catapillar card");songTrack=29; MP3tracks(); }
      //voice: catapillar is in the yard
      if (tagID == tag_UID16){Serial.println("goose card");songTrack=30; MP3tracks(); }
      //voice: goose is in the yard

    }//end of if (adventureSwitch>0)
      switch (adventureSwitch)
      {
        case 0: //inital set of instructions
        {
            if (attemptNumber==1)
              {
                Serial.println("  cow, goat, rabbit, snake, sheep, bear, rat, chicken.");
                songTrack=2; MP3tracks();//voice: goat, cow, rabbit, snake, sheep, bear, rat, chicken 
              }
            if (attemptNumber==2)
              {
                Serial.println("  lion, aligator, cat, kangaroo, hippo, duck, goose, catapillar.");
                songTrack=14; MP3tracks();//voice: lion, aligator, cat, kangaroo, hippo, duck, goose, catapillar 
              }
            if (attemptNumber==3)
              {
                Serial.println("  bear, snake, cat, duck, cow, catapillar, rabbit, kangaroo.");
                songTrack=31; MP3tracks();//voice: bear, snake, cat, duck, cow, catapillar, rabbit, kangaroo 
              }

          
          while(digitalRead(busy)==HIGH){/*wait here until track is complete*/}
          Serial.println("place first animal");
          Serial.println(""); //line break in serial printing
          songTrack=3;//voice: place first animal
          adventureSwitch=1;
          break;
        }//end of case 0

        case 1:
        {
        if (attemptNumber==1){if (tagID!=tag_UID1){correctEntry=false;}} //cow
        if (attemptNumber==2){if (tagID!=tag_UID6){correctEntry=false;}} //lion
        if (attemptNumber==3){if (tagID!=tag_UID8){correctEntry=false;}} //bear
          Serial.println("place second animal");
          songTrack=4;//voice: place second animal
          adventureSwitch=2;
          break;
        }//end of case 1
        
        case 2:
        {
        if (attemptNumber==1){if (tagID!=tag_UID2){correctEntry=false;}} //goat
        if (attemptNumber==2){if (tagID!=tag_UID11){correctEntry=false;}} //aligator 
        if (attemptNumber==3){if (tagID!=tag_UID4){correctEntry=false;}} //snake
          Serial.println("place third animal");
          songTrack=5;//voice: place third animal
          adventureSwitch=3;
          break;
        }//end of case 2
        
        case 3:
        {
        if (attemptNumber==1){if (tagID!=tag_UID3){correctEntry=false;}} //rabbit
        if (attemptNumber==2){if (tagID!=tag_UID12){correctEntry=false;}} //cat
        if (attemptNumber==3){if (tagID!=tag_UID12){correctEntry=false;}} //cat
          Serial.println("place fourth animal");
          songTrack=6;//voice: place fourth animal
          adventureSwitch=4;
          break;
        }//end of case 3
        
        case 4:
        {
        if (attemptNumber==1){if (tagID!=tag_UID4){correctEntry=false;}} //snake 
        if (attemptNumber==2){if (tagID!=tag_UID13){correctEntry=false;}} //kangroo
        if (attemptNumber==3){if (tagID!=tag_UID7){correctEntry=false;}} //duck
          Serial.println("place fifth animal");
          songTrack=7;//voice: place fifth animal
          adventureSwitch=5;
          break;
        }//end of case 4
        
        case 5:
        {
        if (attemptNumber==1){if (tagID!=tag_UID9){correctEntry=false;}} //sheep 
        if (attemptNumber==2){if (tagID!=tag_UID5){correctEntry=false;}} //hippo
        if (attemptNumber==3){if (tagID!=tag_UID1){correctEntry=false;}} //cow
          Serial.println("place sixth animal");
          songTrack=8;//voice: place sixth animal
          adventureSwitch=6;
          break;
        }//end of case 5
        
        case 6:
        {
        if (attemptNumber==1){if (tagID!=tag_UID8){correctEntry=false;}} //bear
        if (attemptNumber==2){if (tagID!=tag_UID7){correctEntry=false;}} //duck
        if (attemptNumber==3){if (tagID!=tag_UID15){correctEntry=false;}} //catapillar
          Serial.println("place seventh animal");
          songTrack=9;//voice: place seventh animal
          adventureSwitch=7;
          break;
        }//end of case 6
        
        case 7:
        {
        if (attemptNumber==1){if (tagID!=tag_UID10){correctEntry=false;}} //rat
        if (attemptNumber==2){if (tagID!=tag_UID16){correctEntry=false;}} //goose
        if (attemptNumber==3){if (tagID!=tag_UID3){correctEntry=false;}} //rabbit
          Serial.println("place eighth animal");
          songTrack=10;//voice: place eighth animal
          adventureSwitch=8;
          break;
        }//end of case 7
        
        case 8:
        {
        if (attemptNumber==1){if (tagID!=tag_UID14){correctEntry=false;}} //chicken
        if (attemptNumber==2){if (tagID!=tag_UID15){correctEntry=false;}} //catapillar
        if (attemptNumber==3){if (tagID!=tag_UID13){correctEntry=false;}} //kangaroo

//code compare section//of case 8//////////////////////////////////////
          delay(3000); // to allow last card entered songTrack to play then proceed
          
          if (correctEntry==true)
            {
              Serial.println("combination entered correctly, box will open, lift lid to remove prize");
              Serial.println(""); //line break in serial printing       
              songTrack=11; MP3tracks();//voice: combination entered correctly, box will now open...'click'...
              while(digitalRead(busy)==LOW){/*wait here for track to finish playing*/}
              boxServo.writeMicroseconds (servoOpen);//box open
              songTrack=12; MP3tracks();// voice: "lift handle and remove prize. Congratulations. End of Adventure"
              delay(6000); //adjust this pause for the previous track to complete before track "power off"
              songTrack=46; MP3tracks(); // voice: "power off"
              shutDown(); //trigger pololu switch to off  
              
            }//end of (correctEntry == true)
      
          if (correctEntry==false) 
            {
              Serial.println("combination entered incorrectly...try again");
             songTrack=13; MP3tracks();//voice: combination entered incorrectly try again
             while(digitalRead(busy)==LOW) {/* wait here until MP3 is done playing*/} 
             adventureSwitch=0; //clear adventureSwitch back to beginning
             correctEntry=true; //clear correctEntry back to start
             attemptNumber++; //index attempt number up one
              if (attemptNumber>=4){attemptNumber=1;} //if fourth attempt has been reached then start over at first order
              Serial.print("attemptNumber is now == "); Serial.println(attemptNumber);
              Serial.println(""); //line break on serial printing
              songTrack=46; MP3tracks(); //voice: "power off"
              shutDown();
            }//end of (correctEntry == false)
             break;
        }//end of case 8
      }//end of switch (adventureSwitch)
  if (adventureSwitch>1)
    {
      Serial.print("correctEntry is ");
      Serial.println(correctEntry);
      Serial.println("1 == code is correct, 0 == code is incorrect.");
      Serial.println("once incorrect will stay that way until next turn start");
      Serial.println(""); //line break in serial printing
    }
  }//end of action()

  void MP3tracks()
  {

    switch (songTrack)
    {
      case 1: //trigger track #1 "Greetings Adventurers!!"
      {
        Serial.println("Greetings adventurers and welcome to your final task.");
        Serial.println("One by one place the animals inside the fence in the following order then remove.");
        Serial.println("You have 45 seconds to enter the combination before shutdown");
        digitalWrite(I00, LOW);
        digitalWrite(I01, HIGH);
        digitalWrite(I02, HIGH);
        digitalWrite(I03, HIGH);
        digitalWrite(I04, HIGH);
        digitalWrite(I05, HIGH);
        break;
      }//end of case 1:

      case 2: //trigger track #2 "cow, goat, rabbit, snake, sheep , bear, rat, chicken"
      {
        digitalWrite(I00, HIGH);
        digitalWrite(I01, LOW);
        digitalWrite(I02, HIGH);
        digitalWrite(I03, HIGH);
        digitalWrite(I04, HIGH);
        digitalWrite(I05, HIGH);
        break;
      }//end of case 2:

      case 3: //trigger track #3
      {
        Serial.println("case 3: place the first animal in the fence, then remove");
        digitalWrite(I00, LOW);
        digitalWrite(I01, LOW);
        digitalWrite(I02, HIGH);
        digitalWrite(I03, HIGH);
        digitalWrite(I04, HIGH);
        digitalWrite(I05, HIGH);
        break;
      }//end of case 3:
      
      case 4: //trigger track #4
      {
        Serial.println("case 4: place the second animal in the fence, then remove");
        digitalWrite(I00, HIGH);
        digitalWrite(I01, HIGH);
        digitalWrite(I02, LOW);
        digitalWrite(I03, HIGH);
        digitalWrite(I04, HIGH);
        digitalWrite(I05, HIGH);
        break;
      }//end of case 4:

      case 5: //trigger track #5
      {
        Serial.println("case 5: place the third animal in the fence, then remove");
        digitalWrite(I00, LOW);
        digitalWrite(I01, HIGH);
        digitalWrite(I02, LOW);
        digitalWrite(I03, HIGH);
        digitalWrite(I04, HIGH);
        digitalWrite(I05, HIGH);
        break;
      }//end of case 5:

      case 6: //trigger track #6
      {
        Serial.println("case 6: place the fourth animal in the fence, then remove");
        digitalWrite(I00, HIGH);
        digitalWrite(I01, LOW);
        digitalWrite(I02, LOW);
        digitalWrite(I03, HIGH);
        digitalWrite(I04, HIGH);
        digitalWrite(I05, HIGH);
        break;
      }//end of case 6:

      case 7: //trigger track #7
      {
        Serial.println("case 7: place the fifth animal in the fence, then remove");
        digitalWrite(I00, HIGH);
        digitalWrite(I01, HIGH);
        digitalWrite(I02, HIGH);
        digitalWrite(I03, LOW);
        digitalWrite(I04, HIGH);
        digitalWrite(I05, HIGH);
        break;
      }//end of case 7:

      case 8: //trigger track #8
      {
        Serial.println("case 8: place the sixth animal in the fence, then remove");
        digitalWrite(I00, HIGH);
        digitalWrite(I01, HIGH);
        digitalWrite(I02, HIGH);
        digitalWrite(I03, LOW);
        digitalWrite(I04, HIGH);
        digitalWrite(I05, HIGH);
        break;
      }//end of case 8:

      case 9: //trigger track #9
      {
        Serial.println("case 9: place the seventh animal in the fence, then remove");
        digitalWrite(I00, LOW);
        digitalWrite(I01, HIGH);
        digitalWrite(I02, HIGH);
        digitalWrite(I03, LOW);
        digitalWrite(I04, HIGH);
        digitalWrite(I05, HIGH);
        break;
      }//end of case 9:

      case 10: //trigger track #10
      {
        Serial.println("case 6: place the eighth animal in the fence, then remove");
        digitalWrite(I00, HIGH);
        digitalWrite(I01, LOW);
        digitalWrite(I02, HIGH);
        digitalWrite(I03, LOW);
        digitalWrite(I04, HIGH);
        digitalWrite(I05, HIGH);
        break;
      }//end of case 10:

      case 11: //trigger track #11 "place eighth animal then remove"
      {
        Serial.println("case 11: combination entered correctly. The box will now unlock");
        digitalWrite(I00, LOW);
        digitalWrite(I01, LOW);
        digitalWrite(I02, HIGH);
        digitalWrite(I03, LOW);
        digitalWrite(I04, HIGH);
        digitalWrite(I05, HIGH);
        break;
      }//end of case 11:

      case 12: //trigger track #12
      {
        Serial.println("case 12: lift handle to remove your prize, congratulations, end of adventure.");
        digitalWrite(I00, HIGH);
        digitalWrite(I01, HIGH);
        digitalWrite(I02, LOW);
        digitalWrite(I03, LOW);
        digitalWrite(I04, HIGH);
        digitalWrite(I05, HIGH);
        break;
      }//end of case 12:

      case 13: //trigger track #13
      {
        Serial.println("case 13: combination entered incorrectly, try again");
        digitalWrite(I00, LOW);
        digitalWrite(I01, HIGH);
        digitalWrite(I02, LOW);
        digitalWrite(I03, LOW);
        digitalWrite(I04, HIGH);
        digitalWrite(I05, HIGH);
        break;
      }//end of case 13:

      case 14: //trigger track #14
      {
        Serial.println("case 14: lion, aligator, cat, kangaroo, hippo, duck, goose, catapillar");
        digitalWrite(I00, HIGH);
        digitalWrite(I01, LOW);
        digitalWrite(I02, LOW);
        digitalWrite(I03, LOW);
        digitalWrite(I04, HIGH);
        digitalWrite(I05, HIGH);
        break;
      }//end of case 14:

      case 15: //trigger track #15
      {
        Serial.println("case 15: cow is in the yard");
        digitalWrite(I00, LOW);
        digitalWrite(I01, LOW);
        digitalWrite(I02, LOW);
        digitalWrite(I03, LOW);
        digitalWrite(I04, HIGH);
        digitalWrite(I05, HIGH);
        break;
      }//end of case 2:

      case 16: //trigger track #16
      {
        Serial.println("case 16: goat is in the yard");
        digitalWrite(I00, HIGH);
        digitalWrite(I01, HIGH);
        digitalWrite(I02, HIGH);
        digitalWrite(I03, HIGH);
        digitalWrite(I04, LOW);
        digitalWrite(I05, HIGH);
        break;
      }//end of case 16:

      case 17: //trigger track #17
      {
        Serial.println("case 17: rabbit is in the yard");
        digitalWrite(I00, LOW);
        digitalWrite(I01, HIGH);
        digitalWrite(I02, HIGH);
        digitalWrite(I03, HIGH);
        digitalWrite(I04, LOW);
        digitalWrite(I05, HIGH);
        break;
      }//end of case 17:

      case 18: //trigger track #18
      {
        Serial.println("case 18: snake is in the yard");
        digitalWrite(I00, HIGH);
        digitalWrite(I01, LOW);
        digitalWrite(I02, HIGH);
        digitalWrite(I03, HIGH);
        digitalWrite(I04, LOW);
        digitalWrite(I05, HIGH);
        break;
      }//end of case 18:

      case 19: //trigger track #19
      {
        Serial.println("case 19: hippo is in the yard");
        digitalWrite(I00, LOW);
        digitalWrite(I01, LOW);
        digitalWrite(I02, HIGH);
        digitalWrite(I03, HIGH);
        digitalWrite(I04, LOW);
        digitalWrite(I05, HIGH);
        break;
      }//end of case 19:

      case 20: //trigger track #20
      {
        Serial.println("case 20: lion is in the yard");
        digitalWrite(I00, HIGH);
        digitalWrite(I01, HIGH);
        digitalWrite(I02, LOW);
        digitalWrite(I03, HIGH);
        digitalWrite(I04, LOW);
        digitalWrite(I05, HIGH);
        break;
      }//end of case 20:

      case 21: //trigger track #21
      {
        Serial.println("case 21: duck is in the yard");
        digitalWrite(I00, LOW);
        digitalWrite(I01, HIGH);
        digitalWrite(I02, LOW);
        digitalWrite(I03, HIGH);
        digitalWrite(I04, LOW);
        digitalWrite(I05, HIGH);
        break;
      }//end of case 21:

      case 22: //trigger track #12
      {
        Serial.println("case 22: bear is in the yard");
        digitalWrite(I00, HIGH);
        digitalWrite(I01, LOW);
        digitalWrite(I02, LOW);
        digitalWrite(I03, HIGH);
        digitalWrite(I04, LOW);
        digitalWrite(I05, HIGH);
        break;
      }//end of case 22:

      case 23: //trigger track #23
      {
        Serial.println("case 23: sheep is in the yard");
        digitalWrite(I00, LOW);
        digitalWrite(I01, LOW);
        digitalWrite(I02, LOW);
        digitalWrite(I03, HIGH);
        digitalWrite(I04, LOW);
        digitalWrite(I05, HIGH);
        break;
      }//end of case 23:

      case 24: //trigger track #24
      {
        Serial.println("case 25: rat is in the yard");
        digitalWrite(I00, HIGH);
        digitalWrite(I01, HIGH);
        digitalWrite(I02, HIGH);
        digitalWrite(I03, LOW);
        digitalWrite(I04, LOW);
        digitalWrite(I05, HIGH);
        break;
      }//end of case 24:

      case 25: //trigger track #25
      {
        Serial.println("case 25: aligator is in the yard");
        digitalWrite(I00, LOW);
        digitalWrite(I01, HIGH);
        digitalWrite(I02, HIGH);
        digitalWrite(I03, LOW);
        digitalWrite(I04, LOW);
        digitalWrite(I05, HIGH);
        break;
      }//end of case 25:

      case 26: //trigger track #26
      {
        Serial.println("case 26: cat is in the yard");
        digitalWrite(I00, HIGH);
        digitalWrite(I01, LOW);
        digitalWrite(I02, HIGH);
        digitalWrite(I03, LOW);
        digitalWrite(I04, LOW);
        digitalWrite(I05, HIGH);
        break;
      }//end of case 26:

      case 27: //trigger track #27
      {
        Serial.println("case 27: kangaroo is in the yard");
        digitalWrite(I00, LOW);
        digitalWrite(I01, LOW);
        digitalWrite(I02, HIGH);
        digitalWrite(I03, LOW);
        digitalWrite(I04, LOW);
        digitalWrite(I05, HIGH);
        break;
      }//end of case 27:

      case 28: //trigger track #28
      {
        Serial.println("case 28: chicken is in the yard");
        digitalWrite(I00, HIGH);
        digitalWrite(I01, HIGH);
        digitalWrite(I02, LOW);
        digitalWrite(I03, LOW);
        digitalWrite(I04, LOW);
        digitalWrite(I05, HIGH);
        break;
      }//end of case 28:

      case 29: //trigger track #29
      {
        Serial.println("case 29: catapillar is in the yard");
        digitalWrite(I00, LOW);
        digitalWrite(I01, HIGH);
        digitalWrite(I02, LOW);
        digitalWrite(I03, LOW);
        digitalWrite(I04, LOW);
        digitalWrite(I05, HIGH);
        break;
      }//end of case 29:

      case 30: //trigger track #30
      {
        Serial.println("case 30: goose is in the yard");
        digitalWrite(I00, HIGH);
        digitalWrite(I01, LOW);
        digitalWrite(I02, LOW);
        digitalWrite(I03, LOW);
        digitalWrite(I04, LOW);
        digitalWrite(I05, HIGH);
        break;
      }//end of case 30:

      case 31: //trigger track #31
      {
        Serial.println("case 31: bear, snake, cat, duck, cow, caterpillar, rabbit, kangaroo");
        digitalWrite(I00, LOW);
        digitalWrite(I01, LOW);
        digitalWrite(I02, LOW);
        digitalWrite(I03, LOW);
        digitalWrite(I04, LOW);
        digitalWrite(I05, HIGH);
        break;
      }//end of case 31:

      case 32: //trigger track #32
      {
        Serial.println("case 32: 30 seconds");
        digitalWrite(I00, HIGH);
        digitalWrite(I01, HIGH);
        digitalWrite(I02, HIGH);
        digitalWrite(I03, HIGH);
        digitalWrite(I04, HIGH);
        digitalWrite(I05, LOW);
        break;
      }//end of case 32:

      case 33: //trigger track #33 "20 seconds"
      {
        Serial.println("case 33: 20 seconds");
        digitalWrite(I00, LOW);
        digitalWrite(I01, HIGH);
        digitalWrite(I02, HIGH);
        digitalWrite(I03, HIGH);
        digitalWrite(I04, HIGH);
        digitalWrite(I05, LOW);
        break;
      }//end of case 33:

      case 34: //trigger track #34 "15 seconds"
      {
        Serial.println("case 34: 15 seconds");
        digitalWrite(I00, HIGH);
        digitalWrite(I01, LOW);
        digitalWrite(I02, HIGH);
        digitalWrite(I03, HIGH);
        digitalWrite(I04, HIGH);
        digitalWrite(I05, LOW);
        break;
      }//end of case 34:

      case 35: //trigger track #35 "10"
      {
        digitalWrite(I00, LOW);
        digitalWrite(I01, LOW);
        digitalWrite(I02, HIGH);
        digitalWrite(I03, HIGH);
        digitalWrite(I04, HIGH);
        digitalWrite(I05, LOW);
        break;
      }//end of case 35:

      case 36: //trigger track #36 "9"
      {
        digitalWrite(I00, HIGH);
        digitalWrite(I01, HIGH);
        digitalWrite(I02, LOW);
        digitalWrite(I03, HIGH);
        digitalWrite(I04, HIGH);
        digitalWrite(I05, LOW);
        break;
      }//end of case 36:

      case 37: //trigger track #37 "8"
      {
        digitalWrite(I00, LOW);
        digitalWrite(I01, HIGH);
        digitalWrite(I02, LOW);
        digitalWrite(I03, HIGH);
        digitalWrite(I04, HIGH);
        digitalWrite(I05, LOW);
        break;
      }//end of case 37:

      case 38: //trigger track #38 "7"
      {
        digitalWrite(I00, HIGH);
        digitalWrite(I01, LOW);
        digitalWrite(I02, LOW);
        digitalWrite(I03, HIGH);
        digitalWrite(I04, HIGH);
        digitalWrite(I05, LOW);
        break;
      }//end of case 38:

      case 39: //trigger track #39 "6"
      {
        digitalWrite(I00, LOW);
        digitalWrite(I01, LOW);
        digitalWrite(I02, LOW);
        digitalWrite(I03, HIGH);
        digitalWrite(I04, HIGH);
        digitalWrite(I05, LOW);
        break;
      }//end of case 39:

      case 40: //trigger track #40 "5"
      {
        digitalWrite(I00, HIGH);
        digitalWrite(I01, HIGH);
        digitalWrite(I02, HIGH);
        digitalWrite(I03, LOW);
        digitalWrite(I04, HIGH);
        digitalWrite(I05, LOW);
        break;
      }//end of case 40:

      case 41: //trigger track #41 "4"
      {
        digitalWrite(I00, LOW);
        digitalWrite(I01, HIGH);
        digitalWrite(I02, HIGH);
        digitalWrite(I03, LOW);
        digitalWrite(I04, HIGH);
        digitalWrite(I05, LOW);
        break;
      }//end of case 41:

      case 42: //trigger track #42 "3"
      {
        digitalWrite(I00, HIGH);
        digitalWrite(I01, LOW);
        digitalWrite(I02, HIGH);
        digitalWrite(I03, LOW);
        digitalWrite(I04, HIGH);
        digitalWrite(I05, LOW);
        break;
      }//end of case 42:

      case 43: //trigger track #43 "2"
      {
        digitalWrite(I00, LOW);
        digitalWrite(I01, LOW);
        digitalWrite(I02, HIGH);
        digitalWrite(I03, LOW);
        digitalWrite(I04, HIGH);
        digitalWrite(I05, LOW);
        break;
      }//end of case 43:

      case 44: //trigger track #44 "1"
      {
        digitalWrite(I00, HIGH);
        digitalWrite(I01, HIGH);
        digitalWrite(I02, LOW);
        digitalWrite(I03, LOW);
        digitalWrite(I04, HIGH);
        digitalWrite(I05, LOW);
        break;
      }//end of case 44:

      case 45: //trigger track #45 "zero"
      {
        digitalWrite(I00, LOW);
        digitalWrite(I01, HIGH);
        digitalWrite(I02, LOW);
        digitalWrite(I03, LOW);
        digitalWrite(I04, HIGH);
        digitalWrite(I05, LOW);
        break;
      }//end of case 45:

      case 46: //trigger track #46 "power off"
      {
        digitalWrite(I00, HIGH);
        digitalWrite(I01, LOW);
        digitalWrite(I02, LOW);
        digitalWrite(I03, LOW);
        digitalWrite(I04, HIGH);
        digitalWrite(I05, LOW);
        delay(750);
        digitalWrite(I00, HIGH);
        digitalWrite(I01, HIGH);
        digitalWrite(I02, HIGH);
        digitalWrite(I03, HIGH);
        digitalWrite(I04, HIGH);
        digitalWrite(I05, HIGH);
        songTrack=100; //clear song track so that loop wont re-trigger mp3tracks
        delay(1000);
        shutDown();
        break;
      }//end of case 46:


    }//end of switch (songTrack)
        //reset all outputs back to 0 (all HIGH)
        delay(500);
        digitalWrite(I00, HIGH);
        digitalWrite(I01, HIGH);
        digitalWrite(I02, HIGH);
        digitalWrite(I03, HIGH);
        digitalWrite(I04, HIGH);
        digitalWrite(I05, HIGH);
        songTrack=100; //clear song track so that loop wont trigger mp3tracks
    
  }//end of void MP3tracks()
  
void countDown()
{
  Serial.print("inside countdown()");
  if (timerVoice>=31){Serial.println(timerVoice);}
  if (timerVoice==0){Serial.println("ShutDown");}
      switch (timerVoice)
    {
       
    case 30:
    {
      Serial.println("30 SECONDS");
      //trigger track 33 - voice: "30 seconds"
      songTrack=32;
      break;
    }

    case 20:
    {
      Serial.println("20 SECONDS");
      //trigger track 34 - voice: "20 seconds"
      songTrack=33;
      break;
    }

    case 15:
    {
      Serial.println("15 SECONDS");
      //trigger track 35 "15 seconds"
      songTrack=34;
      break;
    }

    case 10:
    {
      Serial.println("10");
      //trigger track 36 "10"
      songTrack=35;
      break;
    }

    case 9:
    {
      Serial.println("9");
      //trigger track 37 "9"
      songTrack=36;
      break;
    }

    case 8:
    {
      Serial.println("8");
      //trigger track 38 "8"
      songTrack=37;
      break;
    }

    case 7:
    {
      Serial.println("7");
      //trigger track 39 "7"
      songTrack=38;
      break;
    }

    case 6:
    {
      Serial.println("6");
      //trigger track 40 "6"
      songTrack=39;
      break;
    }

    case 5:
    {
      Serial.println("5");
      //trigger track 41 "5"
      songTrack=40;
      break;
    }

    case 4:
    {
      Serial.println("4");
      //trigger track 42 "4"
      songTrack=41;
      break;
    }

    case 3:
    {
      Serial.println("3");
      //trigger track 43 "3"
      songTrack=42;
      break;
    }

    case 2:
    {
      Serial.println("2");
      //trigger track 44 "2"
      songTrack=43;
      break;
    }

    case 1:
    {
      Serial.println("1");
      //trigger track 45 "1"
      songTrack=44;
      break;
    }

    case 0:
    {
      Serial.println("zero");
      //trigger track 46 "zero"
      songTrack=45;
      break;
    }
  }//end of switch(timerVoice)
}//end of countDown()

void shutDown() //come here if the timer has elapsed, code entered wrong or end of adventure
    {
    attemptNumber++; //index attempt number
    if (attemptNumber>3){attemptNumber=1;} //if attempt number is higher than 3 then roll back to 1
    EEPROM.write(0, attemptNumber); // write the new attempt number to EEPROM to be loaded upon restart
    digitalWrite(shutOff, HIGH); //trigger pololu switch to turn off system
    //if pololu switch is enabled program will never reach here
    Serial.println("just before while(1) in shutoff");
    while(1) {Serial.println("shutdown - inside while(1) @ line 1058, press board reset to exit");}
    /*dead end here, press board reset to exit*/
    }//end of shutDown

    //End of program adventure hope you have fun with this. :p
    //written by E.Linville 6-25-23
